MarkdownConfig class

use MarkdownConfig to set various configurations for MarkdownWidget

Constructors

MarkdownConfig({List<WidgetConfig> configs = const []})

Properties

a → LinkConfig
no setter
blockquote → BlockquoteConfig
no setter
code → CodeConfig
no setter
h1 → HeadingConfig
no setter
h2 → HeadingConfig
no setter
h3 → HeadingConfig
no setter
h4 → HeadingConfig
no setter
h5 → HeadingConfig
no setter
h6 → HeadingConfig
no setter
hashCode → int
The hash code for this object.
no setterinherited
hr → HrConfig
no setter
img → ImgConfig
no setter
input → CheckBoxConfig
no setter
li → ListConfig
no setter
p → PConfig
no setter
pre → PreConfig
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → TableConfig
no setter

Methods

copy({List<WidgetConfig> configs = const []}) → MarkdownConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

darkConfig → MarkdownConfig
darkConfig is used for dark mode
no setter
defaultConfig → MarkdownConfig
default MarkdownConfig for MarkdownWidget
no setter