TocItemBuilderData class

pass TocItemBuilderData to help build your own TocItemBuilder

Constructors

TocItemBuilderData(int index, Toc toc, int currentIndex, ValueChanged<int> refreshIndexCallback)

Properties

currentIndex → int
current selected index of item
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
the index of item
final
refreshIndexCallback → ValueChanged<int>
use refreshIndexCallback to change currentIndex
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toc → Toc
the toc data
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited