CodeNode class

Tag: MarkdownTag.code the code textSpan

Inheritance

Constructors

CodeNode(String text, CodeConfig codeConfig)

Properties

children → List<SpanNode>
finalinherited
childrenSpan → TextSpan
no setterinherited
codeConfig → CodeConfig
final
hashCode → int
The hash code for this object.
no setterinherited
parent → SpanNode?
no setterinherited
parentStyle → TextStyle?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ TextStyle
getter/setter pairinherited-setteroverride-getter
text → String
final

Methods

accept(SpanNode? node) → void
use accept to add a child
inherited
build() → InlineSpan
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAccepted(SpanNode parent) → void
when this node was accepted by it's parent, onAccepted will be triggered
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited