ImgConfig class

config class for image, tag: img

Implemented types

Constructors

ImgConfig({ImgBuilder? builder, ErrorImgBuilder? errorBuilder})
const

Properties

builder → ImgBuilder?
use builder to return a custom image
final
errorBuilder → ErrorImgBuilder?
use errorBuilder to return a custom error image
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
every config has a tag
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited